
# get directory of samples
inpath = paste(script.dir,"/data/","CCA",sep="")
D1 = list.files(paste(inpath))

# pre-allocate
expNames = vector(,length(D1))
fwhm_v1_means = vector(,length(D1))
fwhm_v1_std = vector(,length(D1))
fwhm_v1_se = vector(,length(D1))
peak_v1_means = vector(,length(D1))
peak_v1_std = vector(,length(D1))
peak_v1_se = vector(,length(D1))
pos_v1_means = vector(,length(D1))
pos_v1_std = vector(,length(D1))
pos_v1_se = vector(,length(D1))
bg_means = vector(,length(D1))
bg_std = vector(,length(D1))
bg_se = vector(,length(D1))
treatment = vector(,length(D1))
speciesInds = vector(,length(D1))
tankInds = vector(,length(D1))
co2 = vector(,length(D1))
light = vector(,length(D1))
flow = vector(,length(D1))
speciesInds = vector(,length(D1))
flumeInds = vector(,length(D1))
individualInds = vector(,length(D1))

# load the metadata
metadata = read.table(paste(script.dir,"/data/","metadata_cca.csv",sep=""),header=TRUE,sep=',',stringsAsFactors = FALSE)

n = 100 # number of spectra per file
fwhm_v1_list = vector(,length(D1)*n)
pos_v1_list = vector(,length(D1)*n)
peak_v1_list = vector(,length(D1)*n)
species_list = vector(,length(D1)*n)
tank_list = vector(,length(D1)*n)
bg_list = vector(,length(D1)*n)
n_good = vector(,length(D1)*n)

# set limits to exclude erroneous spectra (needed to remove spectra that missed sample and to remove spectra contaminated by cosmic rays)
peakLim = 50 # minimum signal
posMin = 1090 # minimum wavenumber
posMax = 1092 # minimum wavenumber
bgLim = 1500 # maximum background
fwhmMin = 7 # minimum width
fwhmMax = 15 # maximum width

# loop to calculate curve parameters for each spectra
for (ii in 1:1:length(D1)) { # loop through individuals
	
# get files within this individual folder (for this CCA analysis, all have only 1 file)
D = D1[ii]

# read the name of the tank and the species
ch1 = strsplit(D,"flume")
ch2 = strsplit(ch1[[1]][2],"_")
flumeInds[ii] = as.numeric(ch2[[1]][1])
specCheck = substr(ch2[[1]][2],1,3)
if (specCheck=="spo"){
	speciesInds[ii] = "sporo"
} else if (specCheck=="neo") {
	speciesInds[ii] = "neo"
}
ch3 = strsplit(ch2[[1]][2],speciesInds[ii])
individualInds[ii] = as.numeric(ch3[[1]][2])

# run the curve fitting routine
source(paste(script.dir,"/code/","Raman_calcs_biogenic_calcite.R",sep=""))

# sync to metadata
if (length(which(metadata$ID %in% individualInds[ii]))>0){
expInds = which(metadata$ID %in% individualInds[ii])
co2[ii] = metadata$CO2[expInds]
light[ii] = metadata$Light[expInds]
flow[ii] = metadata$Flow[expInds]
}

# add to full list of curve parameters
fwhm_v1_list[seq(ii*n-n+1,ii*n,1)] = fwhm_v1
pos_v1_list[seq(ii*n-n+1,ii*n,1)] = pos_v1
peak_v1_list[seq(ii*n-n+1,ii*n,1)] = peak_v1
bg_list[seq(ii*n-n+1,ii*n,1)] = bg
species_list[seq(ii*n-n+1,ii*n,1)] = rep(speciesInds[ii],n)
tank_list[seq(ii*n-n+1,ii*n,1)] = rep(tankInds[ii],n)

# remove data in which curves were not fit (generally spots that missed the samples)
fwhm_v1 = fwhm_v1[which(bg!="NA")]
peak_v1 = peak_v1[which(bg!="NA")]
pos_v1 = pos_v1[which(bg!="NA")]
bg = bg[which(bg!="NA")]

# calculate means, standard deviations, and standard errors for curve parameters, applying the filtering criteria listed above to remove erroneous spectra
fwhm_v1_means[ii] = mean(fwhm_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])
fwhm_v1_std[ii] = sd(fwhm_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])
fwhm_v1_se[ii] = sd(fwhm_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])/sqrt(length(D))

peak_v1_means[ii] = mean(peak_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])
peak_v1_std[ii] = sd(peak_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])
peak_v1_se[ii] = sd(peak_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])/sqrt(length(D))

pos_v1_means[ii] = mean(pos_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])
pos_v1_std[ii] = sd(pos_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])
pos_v1_se[ii] = sd(pos_v1[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])/sqrt(length(D))

bg_means[ii] = mean(bg[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])
bg_std[ii] = sd(bg[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])
bg_se[ii] = sd(bg[which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim)])/sqrt(length(D))

n_good[ii] = length(which(fwhm_v1> fwhmMin & fwhm_v1<fwhmMax & pos_v1> posMin & pos_v1< posMax & peak_v1>peakLim & bg<bgLim))

} # end of curve-fitting loops

# filter the vectors that are storing all of the individual curve parameters
fwhm_v1_list[which(fwhm_v1_list<fwhmMin | fwhm_v1_list> fwhmMax | pos_v1_list<posMin | pos_v1< posMax | peak_v1_list<peakLim | bg_list>bgLim)] = NA
pos_v1_list[which(fwhm_v1_list<fwhmMin | fwhm_v1_list> fwhmMax | pos_v1_list<posMin | pos_v1< posMax | peak_v1_list<peakLim | bg_list>bgLim)] = NA
peak_v1_list[which(fwhm_v1_list<fwhmMin | fwhm_v1_list> fwhmMax | pos_v1_list<posMin | pos_v1< posMax | peak_v1_list<peakLim | bg_list>bgLim)] = NA
bg_list[which(fwhm_v1_list<fwhmMin | fwhm_v1_list> fwhmMax | pos_v1_list<posMin | pos_v1< posMax | peak_v1_list<peakLim | bg_list>bgLim)] = NA


# Si chip corrections
source(paste(script.dir,"/code/","ramanFit_silicon.R",sep=""))
D2 = paste(script.dir,"/data/","Si_chip/",list.files(paste(script.dir,"/data/","Si_chip/",sep=""), pattern='*.txt'), sep="")
Si_position_means = vector(,length(script.dir))
Si_position_ends = vector(,length(script.dir))
Si_position_start = vector(,length(script.dir))


	Si_position = vector(,length(D2))
	
	for (jj in 1:1:length(D2)) {
	
	# read the spectra
	thisRaman<-read.table(D2[jj],header=F,sep='\t')

	wavenumber = thisRaman[,1]
	intensity = thisRaman[,2]
	fits = try(ramanFit_silicon(wavenumber,intensity),silent=TRUE)
	
	this_pos = fits[3]
	Si_position[jj] = this_pos[[1]]
	
	
	}
	
	Si_position_means = mean(Si_position)
	Si_position_ends = mean(Si_position[seq(length(Si_position)-2,length(Si_position),1)])
	Si_position_start = mean(Si_position[seq(1,3,1)])


# Mg/Ca corrections:

# our measured Mg:
Mg_measured_per = (MgCa_measured/1000)/(1-(MgCa_measured/1000))*100

posCalib = Si_position_means - 520.7 # this is in 1/cm calibration of our instrument position based on the measured position of the primary silicon peak (measured at 522, nominally it should be 520.7)

# Method 1a: Using Bischoff et al 1985 data
Mg_B85 = ((pos_v1_means-posCalib)-1084.868)/0.231 # estimate Mg mol% from peak position
fwhm_B85 = 3.1241+ Mg_B85*0.5019 # estimate FWHM from peak position
residual_B85_fwhm_v1 = fwhm_v1_means - fwhm_B85 # residual fwhm

# Method 1b: Using Bischoff et al 1985 regression but our Mg data
#fwhm_B85_ourMg = 3.1241+ Mg_measured_per*0.5019 # estimate FWHM from peak position
#residual_B85_fwhm_v1_ourMg = fwhm_v1_means - fwhm_B85_ourMg # residual fwhm

# Method 2a: Using Perrin et al 2016 data
# (they present high-order polynomials, but over the range 0-20 mol% Mg, relationship is effectively linear)
xMg = seq(1,25,0.1) # using this to linearize their data
P16_function = 1086.2 + 0.22*xMg - 0.00276*xMg^2 + 0.000106*xMg^3
P16_linear = lm(P16_function~xMg) # linear fit
P16_silicon_calib = -0.2 # their offset calibration
Mg_P16 = ((pos_v1_means-posCalib+P16_silicon_calib)-coef(P16_linear)[[1]])/coef(P16_linear)[[2]] # estimate Mg mol% from peak position
fwhm_P16 = 3.61 + 0.51*Mg_P16 - 0.00787*Mg_P16^2 # estimate FWHM from peak position
residual_P16_fwhm_v1 = fwhm_v1_means - fwhm_P16 # residual fwhm

# Method 2b: Using Perrin et al 2016 regression but our Mg data
#fwhm_P16_ourMg = 3.61 + 0.51* Mg_measured_per - 0.00787* Mg_measured_per ^2 # estimate FWHM from peak position
#residual_P16_fwhm_v1_ourMg = fwhm_v1_means - fwhm_P16_ourMg # residual fwhm

# can also calculate Mg % from Borromeo et al 2017, but no regression to fwhm was presented
Mg_B17 = ((pos_v1_means-posCalib)-1086.2)/0.1491



# sort for output
ord1 = order(speciesInds)
ord1a = ord1[which(speciesInds[ord1]=="sporo")]
ord1b = ord1[which(speciesInds[ord1]=="neo")]
ord2a = ord1a[order(flumeInds[ord1a])]
ord2b = ord1b[order(flumeInds[ord1b])]
ord = c(ord2a,ord2b)

data_out = data.frame(speciesInds[ord], co2[ord], light[ord], flow[ord], flumeInds[ord], individualInds[ord], fwhm_v1_means[ord], fwhm_v1_se[ord], residual_P16_fwhm_v1[ord], pos_v1_means[ord], pos_v1_se[ord], Mg_P16[ord], Mg_B17[ord], n_good[ord])
colnames(data_out) = c("species", "CO2", "Light", "Flow", "flume number", "individual number", "raw FWHM (1/cm)", "FWHM standard error", "residual FWHM from Perrin 2016", "raw wavenumber (1/cm)", "wavenumber standard error", "mole % Mg from Perrin 2016", "mole % Mg from Borromeo 2017", "number good spectra")
write.csv(data_out,file=paste(script.dir,"/output/","flume_CCA_output.csv",sep=""), row.names=FALSE)

