ramanFit_silicon <- function(wavenumber,intensity){
	
	 	
	# locate the data between 510 and 540 cm^-1 (i.e. the first silicon peak)
	inds = which(wavenumber < 538 & wavenumber > 510)
	
	# define x as cm^-1 and r as the intensity
	x = wavenumber[inds]
	r = intensity[inds]
	
	# make a data frame for curve fitting
	v1 = data.frame(x,r)

	peakGuess = max(v1)-min(v1)
	
	# non-linear least squares fitting: background intercept and slope, and Gaussian curve
	thisFit_Si = try(nls(r ~ b + m*x + k * exp(-((x-p))^2/(2*sd^2)), data=v1, start = list(b=600,k=peakGuess,p=522,sd=4,m=0)),silent=TRUE)
	
	if (length(thisFit_v1)>1) {
		# define full width at half maximum (FWHM), peak height, and peak position from the Gaussian fit
		fwhm_Si = abs(coef(thisFit_Si)[4]*2*sqrt(2*log(2)))
		peak_Si = coef(thisFit_Si)[2]
		pos_Si = coef(thisFit_Si)[3]
		background = coef(thisFit_Si)[1]+coef(thisFit_Si)[5]*coef(thisFit_Si)[3]
		}
	if (length(thisFit_Si)==1) {
		print("Error: convergence not reached. Try adjusting 'start' values of nls function")
		}
		
	out = list(fwhm_Si,peak_Si,pos_Si,background,thisFit_Si)
	return(out)
		
	}


